Index: /trunk/PS-IPP-Metadata-Config/lib/PS/IPP/Metadata/Config.pod
===================================================================
--- /trunk/PS-IPP-Metadata-Config/lib/PS/IPP/Metadata/Config.pod	(revision 3357)
+++ /trunk/PS-IPP-Metadata-Config/lib/PS/IPP/Metadata/Config.pod	(revision 3358)
@@ -81,5 +81,14 @@
 =head1 DEVELOPER NOTES
 
-=head2 REFERENCES
+Currently, "multiple symbols" are translated into "STR" vectors as the
+appropriate behavior isn't clear in the psLib SDRS.
+
+The parser does not have complete support for all of C99's floating point
+constants or any support for complex numbers.
+
+None of the "extended" config language syntax, as defined in the SDRS, is
+supported.
+
+=head1 REFERENCES
 
 =over 4

Index: /trunk/PS-IPP-Metadata-Config/lib/PS/IPP/Metadata/Config.pm
===================================================================
--- /trunk/PS-IPP-Metadata-Config/lib/PS/IPP/Metadata/Config.pm	(revision 3357)
+++ /trunk/PS-IPP-Metadata-Config/lib/PS/IPP/Metadata/Config.pm	(revision 3358)
@@ -1,5 +1,5 @@
 # Copyright (c) 2005  Joshua Hoblitt
 #
-# $Id#
+# $Id: Config.pm,v 1.2 2005-03-01 23:45:21 jhoblitt Exp $
 
 package PS::IPP::Metadata::Config;
@@ -12,5 +12,4 @@
 use Carp qw( carp );
 use Parse::RecDescent;
-#use Data::Dumper;
 
 use base qw( Class::Accessor::Fast );
@@ -44,9 +43,9 @@
     $self->_strip_comments( $tree ) or return undef;
 
-    # handle multi-declare lines
-    $self->_merge_multi_declares( $tree ) or return undef;
+    # handle multi-symbol lines
+    $self->_merge_multi_symbols( $tree ) or return undef;
 
     # look for duplicate names, there should be none after processing the
-    # multi-declares
+    # multi-symbols
     $self->_merge_duplicates( $tree ) or return undef;
 
@@ -57,5 +56,5 @@
     my ( $self, $tree ) = @_;
 
-    # Iteratate through the AoH structure and remove the hashes that have a
+    # Iteratate through the parse tree and remove the hashes that have a
     # class key equal to "comment_line".
     for (my $i = 0; $i < @{$tree}; $i++) {
@@ -75,17 +74,17 @@
 }
 
-sub _merge_multi_declares {
+sub _merge_multi_symbols {
     my ( $self, $tree ) = @_;
 
     # list of valid multi-declares
     my %multis;
 
     # Iteratate through the AoH structure looking for multi-declare
     # declarations.  This is done in a single pass so multi-declares must
     # actually be 'declared' before any member elements appear.  
     for (my $i = 0; $i < @{$tree}; $i++) {
         my $elem = $tree->[$i];
 
-        if ( $elem->{class} eq "multi_declare" ) {
+        if ( $elem->{class} eq "multi_symbol" ) {
             # construct a valid parse spec
             my $node = {
@@ -96,9 +95,8 @@
             };
 
             # add to list of valid multi-declares
             $multis{ $elem->{name} } = $node;
 
-            # delete mult-declare hash from the array and replace it with the
-            # valid spec
+            # delete multi-symbol hash from the parse tree and replace it
             splice @$tree, $i, 1, $node;
 
@@ -108,5 +106,5 @@
         if ( my $node = $multis{ $elem->{name} } ) {
             if ( ! $elem->{type} =~ /STR|STRING/ ) {
-                carp "multi-declare element, ",
+                carp "multi-symbol element, ",
                      $elem->{name},
                      "has type of ",
@@ -116,5 +114,5 @@
             }
 
             # add element value to the appropriate multi-declare element
             my $vec = $node->{value};
             push( @$vec, $elem->{value} );
@@ -138,4 +136,6 @@
     my %names;
 
+    # Iteratate through the parse tree looking for duplicate declarations and
+    # resolving them by discarding elements according to the value of 'overwrite'.
     for (my $i = 0; $i < @{$tree}; $i++) {
         my $elem = $tree->[$i];
@@ -171,5 +171,5 @@
     scalar
     | vector
-    | multi_declare
+    | multi_symbol
     | comment_line
 
@@ -219,8 +219,8 @@
          }}
 
-multi_declare:
+multi_symbol:
     name '*' end_of_line
         {{
-            class   => 'multi_declare',
+            class   => 'multi_symbol',
             name    => $item{name}, 
             comment => $item{end_of_line},
@@ -75,17 +74,17 @@
     my ( $self, $tree ) = @_;
 
-    # list of valid multi-declares
+    # list of valid multi-symbols
     my %multis;
 
@@ -75,17 +74,17 @@
     my %multis;
 
-    # Iteratate through the AoH structure looking for multi-declare
-    # declarations.  This is done in a single pass so multi-declares must
+    # Iteratate through the parse tree looking for multi-symbol
+    # declarations.  This is done in a single pass so multi-symbols must
     # actually be 'declared' before any member elements appear.  
     for (my $i = 0; $i < @{$tree}; $i++) {
@@ -96,9 +95,8 @@
             };
 
-            # add to list of valid multi-declares
+            # add to list of valid multi-symbols
             $multis{ $elem->{name} } = $node;
 
@@ -116,5 +114,5 @@
             }
 
-            # add element value to the appropriate multi-declare element
+            # add element value to the appropriate multi-symbol element
             my $vec = $node->{value};
             push( @$vec, $elem->{value} );